@@ -523,14 +523,27 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 void DetailWindow::modifyFields() {
 	if (createFieldDlg.isNull()) {
+		for (int i = 0; i < target->fields.count(); i++) {
+			TargetField * field = target->fields[i];
+			//qDebug () << "getting field " << i;
+
+			field->name = labels[i]->text();
+			if (field->type == TYPE_TEXT) {
+				//qDebug () << "getting TEX field " << i;
+				field->value = ((QTextEdit*)values[i])->toPlainText();
+				fieldsChanged |= ((QTextEdit*)values[i])->document ()->isModified ();
+			}
+			else {
+				//qDebug () << "getting LIN field " << i;
+				field->value = ((QLineEdit*)values[i])->text();
+				fieldsChanged |= ((QLineEdit*)values[i])->isModified();
+			}
+		}
+
 		createFieldDlg = new CreateFieldDialog(this->target, this);
 		createFieldDlg->setMinimumSize(size().width(),size().height()-100);
 		createFieldDlg->exec();
 
-
-
-		////qDebug () << "NOW ";
-
 		showFields ();
 
 		delete createFieldDlg;
@@ -1048,23 +1061,31 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 			if (tmp->userData(0) != NULL) {
 				TargetField * f = ((ButtonInfo *)tmp->userData(0))->field;
 
-				QMenu menu(this);
-		    	if (f->type == TYPE_URL) {
-					menu.addAction(tr("Go to"), tmp, SLOT(m_goto()));
-					menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
-		    		//QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
-		    	}
-		    	else {
-	    			if (f->type == TYPE_PHONE_NUMBER) {
-	    				menu.addAction(tr("Call to"), tmp, SLOT(m_call()));
-	    				//menu.addAction(tr("SMS to"), tmp, SLOT(m_sms()));
-	    				menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
-	    			}
-	    			else {
-	    				menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
-	    			}
-		    	}
-				menu.exec(_p);
+				if (f->value != NULL && f->value.length() > 0) {
+					QMenu menu(this);
+					if (f->type == TYPE_URL) {
+						menu.addAction(tr("Go to"), tmp, SLOT(m_goto()));
+						menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
+						//QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
+					}
+					else {
+						if (f->type == TYPE_PHONE_NUMBER) {
+							QString telf = f->value;
+							telf = telf.simplified();
+							telf = telf.replace(" ", "");
+
+							if (telf.length() > 0) {
+								menu.addAction(tr("Call to").arg(telf), tmp, SLOT(m_call()));
+							}
+							//menu.addAction(tr("SMS to"), tmp, SLOT(m_sms()));
+							menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
+						}
+						else {
+							menu.addAction(tr("Copy"), tmp, SLOT(m_copy()));
+						}
+					}
+					menu.exec(_p);
+				}
 			}
 		}
 	}
@@ -1364,6 +1385,9 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 			QMessageBox * messageBox = new QMessageBox(this);
 			int b = messageBox->information(this, "Wallet", tr("Are you sure you want to discard changes?"), QMessageBox::Yes, QMessageBox::No);
 			if (b == QMessageBox::Yes) {
+				target->freeFieldList();
+				target->freeResources();
+
 				event->accept();
 			}
 			else {
@@ -1371,11 +1395,16 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 			}
 			delete messageBox;
 		}
-		else
+		else {
+			target->freeFieldList();
+			target->freeResources();
+
 			event->accept();
+		}
 	}
-	else
+	else {
 		event->accept();
+	}
 }
 
 CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
@@ -1392,6 +1421,8 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 	for (int i = 0; i < this->target->fields.size(); i++) {
 		TargetField * item = new TargetField(this->target->fields.at(i));
 		fields.append(item);
+
+		//qDebug () << "field " << i << " -> " << item->value;
 	}
 
 	setContextMenuPolicy(Qt::NoContextMenu);
@@ -1619,6 +1650,7 @@ void CreateFieldDialog::save () {
 		// REMOVE PREVIOUS
 		for (int i = 0; i < this->target->fields.size(); i++) {
 			TargetField * item = this->target->fields.at(i);
+
 			delete item;
 		}
 		this->target->fields.clear();
@@ -1627,6 +1659,8 @@ void CreateFieldDialog::save () {
 		for (int i = 0; i < fields.size(); i++) {
 			TargetField * item = new TargetField(fields.at(i));
 			this->target->fields.append(item);
+
+			//qDebug () << "field " << i << " -> " << item->value;
 		}
 
 		parent->fieldsChanged = _fieldsChanged;
