@@ -651,7 +651,7 @@ void eWallet::loadTypesAndFields () {
 	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Authority"),TYPE_STRING, true, 8,"Authority"));
 	  this->types->append(QString("Note Card"));
 	  this->fieldsByType->append (new QList<TargetField>);
-	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Text"),TYPE_STRING, true, 2,"Text"));
+	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Text"),TYPE_TEXT, true, 2,"Text"));
 	  this->types->append(QString("Car Info"));
 	  this->fieldsByType->append (new QList<TargetField>);
 	  this->fieldsByType->at(this->types->length() - 1)->append(TargetField(tr("Model"),TYPE_STRING, true, 2,"Model"));
@@ -1010,6 +1010,7 @@ void eWallet::createMenu()
 		menuBar()->addAction(tr("Merge DB"), this, SLOT(mergeDB()));
 		//menuBar()->addAction(tr("Change View"), this, SLOT(changeMode()));
 		menuBar()->addAction(tr("Change Password"), this, SLOT(changePassword()));
+		menuBar()->addAction(tr("About"), this, SLOT(about()));
 		menuBar()->addAction(tr("Exit"), QApplication::instance(), SLOT(quit()));
 	}
 #else
@@ -1945,6 +1946,7 @@ void eWallet::askPassword () {
 }
 
 void eWallet::about() {
+	//this->setStyleSheet("QMessageBox#A { background-color: yellow }");
 	QMessageBox::about(this, tr("About Wallet"), tr("<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"\
 			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
 			"<p>Icons by http://pixelmixer.ru/</p>"\
